aboutsummaryrefslogtreecommitdiffstats
path: root/Types.h
diff options
context:
space:
mode:
authorLiana Husikyan <liana@ethdev.com>2015-03-24 18:11:27 +0800
committerLiana Husikyan <liana@ethdev.com>2015-03-25 20:59:46 +0800
commit9986b072ad471908df4402ef860e58e331035948 (patch)
tree6bf7625fdbfe4f76e655027bdb421f084f6a58df /Types.h
parent701b34fbeb1bd08445aad55f82672d35343f5a44 (diff)
downloaddexon-solidity-9986b072ad471908df4402ef860e58e331035948.tar.gz
dexon-solidity-9986b072ad471908df4402ef860e58e331035948.tar.zst
dexon-solidity-9986b072ad471908df4402ef860e58e331035948.zip
renamed externalTypes to externalSignature
Diffstat (limited to 'Types.h')
-rw-r--r--Types.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/Types.h b/Types.h
index 599d80cc..e00e6b98 100644
--- a/Types.h
+++ b/Types.h
@@ -550,10 +550,10 @@ public:
virtual MemberList const& getMembers() const override;
Location const& getLocation() const { return m_location; }
/// @returns the external type of this function type given the function name
/// If @a _name is not provided (empty string) then the @c m_declaration member of the
/// function type is used
- std::string externalTypes(std::string const& _name = "") const;
+ std::string externalSignature(std::string const& _name = "") const;
Declaration const& getDeclaration() const
{
solAssert(m_declaration, "Requested declaration from a FunctionType that has none");
@@ -550,10 +550,10 @@ public:
virtual MemberList const& getMembers() const override;
Location const& getLocation() const { return m_location; }
- /// @returns the external type of this function type given the function name
+ /// @returns the external signature of this function type given the function name
/// If @a _name is not provided (empty string) then the @c m_declaration member of the
/// function type is used